.\"
.\" DI $Id: utmac.tr,v 1.33 2013/10/30 20:31:07 pj Exp pj $
.\" DA Pierre‐Jean Fichet
.\" DS Utroff utmac manual
.\" DT Utroff utmac manual
.\" DK utroff utmac u‐ref uw ux um ut us uh refer iso‐690 troff nroff heirloom tmac xml pdf markdown html fodt
.
.
.
.TH UTMAC 7 '2014‐03‐17'
.
.
.
.SH NAME
.PP
\fButmac\fP: macro set for heirloom troff.
.
.
.
.SH DESCRIPTION
.PP
The \fIU troff macros\fP — \fIutmac\fP — is a set of
\fItroff\fP macros which uses the typographic features of
\fIHeirloom Troff\fP. Bibliography, indexes, table of
content and summaries can be automatically inserted.
\fIUtmac\fP informs about orphans, widows and blanks at the
bottom of page, and provides macros to help the user to fix
them manually. \fIUtmac\fP can produce terminal output, high
quality pdf files, ReStructuredText files, plain text file,
and clean xml files — and so, with some xsl stylesheet,
flat open document texts (fodt) and html files.
.
.
.
.SH FILES
.
.
.
.SS User macro files
.RS 3
.PP
The following macro files can be used by the user (called
with the \fB‐m\fR option of troff):
.TP
\fIuh\fR
Made with humanities in mind. It use marginal notes instead
of footnotes.
.TP
\fIum\fP
Translate a \fIutmac\fR document to manpage with \fInroff\fR.
.TP
\fIut\fP
Translate an \fIutmac\fR document to a flat text file (such as
README files) with \fInroff\fR.
.TP
\fIus\fP
Made for technical documentation. It use a common
layout, almost like the old troff \fIms\fR.
.TP
\fIuw\fP
Translate an \fIutmac\fR document to the markdown wiki format.
.TP
\fIux\fP
Translate an \fIutmac\fR document to xml. This macro must be
used with the
postxml(1)
post‐processor.
.
.
.
.SS Locale macro files
.RS 3
.PP
\fIUtmac\fR use the \fBUTMAC\fR environment variable to load a
locale macro. The file \fI@MACDIR@/u‐locale\fR is an
example of such a macro, you should copy and edit it to suit
your needs.
.
.
.
.SS Internal macro files
.RS 3
.PP
The following macros files are internally used by
\fIutmac\fR:
.TP
\fIu‐ref\fP
Format a refer bibliography. See
u‐ref(7).
.TP
\fIu‐grind\fP
Handle \fIugrind\fR pre‐processor.
.TP
\fIu‐idx\fP
Inline and index macros.
.TP
\fIu‐en\fR \fIu‐fr\fR
Localization macros, for english and french. They should be
loaded by the file defined by the \fBUTMAC\fR environment
variable. If the \fBUTMAC\fR environment variable is not
defined, english is loaded.
.TP
\fIu‐apolline\fR, \fIu‐libertine\fR
Font macro, for the opentype apolline and libertine font. If the
\fBUTMAC\fR environment variable is not defined,
\fIu‐libertine\fR is loaded.
.
.
.
.SH MACROS
.PP
An \fIutmac\fP document should be structured in four parts:
metadatas, definition of some register, content, and appendix. The
content can contain header macros, summary macros, paragraph
macros, typographic macros, note macros, inline
macros, and utmac tests macro.
.PP
All macros have two letters; the first one define the gender
of the macro (meta\fBD\fPatas, \fBR\fRegister,
\fBU\fPtmac tests, \fBH\fPeading, \fBS\fPummary,
\fBP\fParagraph, \fBT\fPypographic, \fBN\fPotes,
in\fBL\fRine, Appendi\fBX\fR.
.
.
.
.SS Metadata macros
.RS 3
.PP
These macro are used to populate the metadatas of the final
file (pdf, xml, or html). They must be inserted in the
first page of the document — their natural place being the
first lines of the file.
.TP
\fBDA\fR \fIauthor name\fP
Define author metadata.
.TP
\fBDI\fR \fIIdentifier\fR
Define identifier (RCS Id...).
.TP
\fBDK\fR \fIlist of keywords\fP
Define keywords metadata.
.TP
\fBDS\fR \fIsubject of the text\fP
Define subject metadata.
.TP
\fBDT\fR \fItitle of the text\fP
Define title metadata.
.
.
.
.SS Register macro to define format and layout
.RS 3
.PP
Some number register are used by \fIutmac\fR to make or not
some actions. Set to 1, the action is done, set to 0, the
action is not done. The following macro can be used to
define the state of this number register. The name of the
macro is also the name of the number register. For example,
\fB.RV 1\fR acts like \fB.nr RV 1\fR. This is usefull to
format a document from the command line:
.PP
.EX
troff -rRV=1 -muh file
.EE
.TP
\fBRV\fP \fInum\fR
If \fInum\fR=1, use a recto‐verso layout.
Default is 0.
.TP
\fBRI\fP \fInum\fR
If \fInum\fR=1, replace references by \fIIdem\fR when
needed.
Default is 1.
.TP
\fBRH\fP \fInum\fR
If \fInum\fR=1, print help message.
Help message inform about orphans, widows, blank at the
bottom of pages, note diverted to next page, and multiple
definition of anchor keyword.
Default is 1.
.TP
\fBRL\fP [\fIfr\fR|\fIen\fR]
Set language of file. Use this macro to localize some string
and to respect local typographic standard if you want to
override the default which should be defined by the macro in
the \fBUTMAC\fR environment variable.
.TP
\fBRO\fP \fInum\fR
If \fInum\fR=1, replace some part of a reference (issuer,
city and date) by \fIop. cit.\fR if the same reference has
appeared in the text.
Default is 1.
.TP
\fBRP\fP \fInum\fR
If \fInum\fR=1, print page number.
Default is 1.
.TP
\fBRN\fP \fInum\fR
If \fInum\fR=1, print reference in a note, if \fInum\fR=0,
the reference is printed directly in the text, by using the
\fBPQ\fR macro.
Default is 1.
.
.
.
.SS Utmac tests macro
.RS 3
.PP
To adapt the content of the document to the macro which is
used, \fIutmac\fR provide a simple test macro:
.TP
\fBUS\fR [\fI!\fR] \fIutmac‐macro\fR \fIcommand\fR
Execute \fIcommand\fR if \fIutmac‐macro\fR is used to format
the document; or, if a \fI!\fR is the first argument,
execute command if \fIutmac‐macro\fR is \fInot\fR used to format
the document. If \fIcommand\fR is preceded by a "\fB.\fR" or
a "\fB'\fR", it’ll be executed, else, the text of
\fIcommand\fR is simply written in the document. \fBUS\fR
macros can be nested to make complex tests.
.PP
The following macro are testable:
\fIuh\fR,
\fIum\fP,
\fIut\fP,
\fIus\fP,
\fIuw\fP,
\fIux\fP,
\fIu‐ref\fP,
\fIu‐grind\fP,
\fIu‐idx\fP,
\fIu‐en\fR,
\fIu‐fr\fR,
\fIu‐apolline\fR,
\fIu‐libertine\fR,
\fIu‐locale\fR.
.PP
For example, here is how to write a special heading for the
um and ux macros:
.PP
.EX
\fB.\fR\fBUS\fR um .H2 UTMAC 7 \fI\e" Manual page heading\fR
\fB.\fR\fBUS\fR ux .H2 UTMAC(7) \fI\e" Xml heading\fR
\fB.\fR\fBUS\fR ! um .US ! ux .H2 Utmac manual page \fI\e" Default heading\fR
.EE
.
.
.
.SS Heading macros
.RS 3
.PP
These macro are used to print headings and to record them
for a summary or a table of contents.
.TP
\fBH1\fP \fITitle of the book\fP
Book heading.
.TP
\fBH2\fP \fITitle of the chapter\fP
Chapter heading.
.TP
\fBH3\fP \fITitle of the paragraph\fP
Paragraph heading.
.TP
\fBH4\fP \fISubheading\fP
Subheading.
.TP
\fBH0\fP \fITemporary title\fP
Temporary heading, printed in the header or in the footer of
the current page. This heading is not recorded in the table
of content.
.TP
\fBH*\fP \fIMargin title\fP
Heading printed in header or footer of the following pages,
and in the current ones if H0 is not set for this page. This
heading is not recorded in the table of content.
.
.
.
.SS Summaries macros
.RS 3
.PP
To print a summary, two or three pass of troff are needed:
the first one to record the summary, the second one to print
it, and a third one might be necessary to adjust the page
number if the summary is longer than one page.
.TP
\fBS2\fP
Print a summary of chapter headings. The summary is printed
on a new page.
.TP
\fBS3\fP
Print a summary of paragraph headings. The summary is
printed on the actual page.
.TP
\fBS4\fP
Print a summary of subheading. The summary is printed on the
actual page.
.TP
\fBS*\fP
Print the whole table of content as a summary.
.
.
.
.SS Paragraph macros
.RS 3
.TP
\fBPB\fR
Left indent (extended) pargraph. Usefull to \fBb\fRegin some
sort of lists.
.TP
\fBPC\fR
Centered paragraph.
.TP
\fBPP\fP
Justified paragraph.
.TP
\fBPQ\fP
Quote paragraph.
.TP
\fBPI\fP [\fIbullet\fP]
List paragraph. Default bullet is usually an emdash
(\fI\e(em\fP).
.TP
\fBPL\fP
Left align paragraph.
.TP
\fBPR\fP
Right align paragraph.
.TP
\fBPX\fP
Example paragraph. Text is not filled.
.
.
.
.SS Typographic macros
.RS 3
.TP
\fBTD\fP
Use micro‐typography to decrease the witdh of a paragraph.
It can be inserted at the begining (just after \fIPP\fP) of
a well choosen paragraph to avoid orphans or widows. A well
chooseen paragraph is a long one, with a short last line.
.TP
\fBTI\fP
Use micro‐typography to increase the width of a paragraph.
It can be inserted at the begining (just after \fIPP\fP) of
a well choosen paragraph to avoid a blank at the bottom of a
page. A well choosen paragraph is a long one, with a long
last line.
.
.
.
.SS Note macros
.RS 3
.TP
\fBNS\fP \fIno\fP
Start a numbered note.
The default is to print a number before the
note, but if an argument is given, no number will be
printed. To insert a number reference to the note in the
text, use the \fB*\fP string, say insert: \fB\e**\fP where
you want the number to appear.
.TP
\fBNT\fP
Print a note on top of the others, or in the flow of the
text, depending of the macro used.
.TP
\fBNB\fP
Print a note in the bottom of the page, or in the flow of
the text, depending of the macro used.
.TP
\fBNE\fP
End \fINS\fP, \fINT\fP or \fINB\fP.
.
.
.
.SS Inline macros
.RS 3
.PP
Inline macros add semantic information to the source and the
final document, define links and anchors, and — for some
of them — index words.
.PP
To deal with all these situations, inline macro have two
usage:
.IP \(bu
By default, an inline macro does an invisible job and doesn’t
print anything;
.IP \(bu
But, if the inline macro is preceded by the \fBLP\fR macro, it
will do its invisible job and print the arguments of
\fBLP\fR macro.
.PP
The following example first index a name (\fBLN\fR macro),
and next print (\fBLP\fR) a link to an url (\fBLU\fR)
address:
.PP
.EX
The
\fB.\fR\fBLN\fR Pierre‐Jean Fichet
author of \fB\e*I\fPutmac\fB\e*R\fP share them on a
\fB.\fR\fBLP\fR website .
\fB.\fR\fBLU\fR http://utroff.org
.EE
.PP
The following inline macro are defined:
.TP
\fBLA\fR \fIacronym meaning\fR
Define an acronym and its meaning, and index them.
.TP
\fBLC\fR \fIcommand\fR
Define a command (does nothing).
.TP
\fBLD\fR \fIdate\fR
Define a date (does nothing).
.TP
\fBLE\fR \fIerror\fR
Define an error (does nothing).
.TP
\fBLK\fR \fIkeyword\fR
Insert an anchor named \fIkeyword\fR.
.TP
\fBLL\fR \fIkeyword\fR
Insert a link to the anchor \fIkeyword\fR. The text to link
is defined by the \fBLP\fR macro.
.TP
\fBLM\fR \fIemail\fR
Insert a link to an email address. The text to link is
defined by the \fBLP\fR macro.
.TP
\fBLN\fR
Define a name and index it.
.TP
\fBLO\fR
Define a name of thing (object) and index it.
.TP
\fBLP\fR
Define text to be printed by an inline macro. The first
argument is the text itself, the second is written after the
text, and the third one is written before it.
.TP
\fBLT\fR \fItitle\fR
Define a title, and index it.
.TP
\fBLU\fR \fIurl\fR
Insert a link to an url. The text to link is defined by the
\fBLP\fR macro.
.TP
\fBLW\fR
Define a word and index it.
.
.
.
.SS Appendix macros
.RS 3
.TP
\fBXB\fP [\fIbibliography\fP]
Print a bibliography. If \fIbibliography\fP is omitted, mh
will use the \fI$REFER\fP environment variable. The bibliography
begin with the \fBH3\fP macro. \fIUtmac\fP try to sort the
bibliography using \fIrefer\fP \fB‐d\fP option, but this
doesn’t give correct result on some bibliography
list. For a perfect result, you should sort your
bibliography with \fIsortbib\fR. See \fBu‐ref\fP(7).
.TP
\fBXI\fP [\fIlist of index to print\fP]
Print all the indexes listed as argument, if existing. If no
argument is given, print all the existing indexes. To index
something, use an inline macro (the second letter of the
inline macro is the index name). Each index begin with the
\fBH3\fP macro.
.TP
\fBXR\fR
Print an index of the title which appeared in references. Is
equivalent to \fB.XI T\fR.
.TP
\fBXT\fP
Print a table of content. The table begin with the \fBH3\fP
macro.
.
.
.
.SH FONTS
.PP
To access a font with \fIutmac\fP, you \fImust\fP use a string
instead of the troff \fB\ef\fP and \fB.fp\fP commands. This
is needed to avoid to know which font will use \fIutmac\fP at
which moment: the string has a different meaning depending
of the context. So, to insert a single letter font, you should
write \fB\e*I\fP, a two letter font \fB\e*(BI\fP, and a more
than two letter font \fB\e*[BIC]\fP.
Strings are defined as follow:
.TP
\fBR\fP
Roman font.
.TP
\fBB\fP
Bold font.
.TP
\fBI\fP
Italic font.
.TP
\fBBI\fP
Bold‐Italic font.
.TP
\fBC\fP
Small Capital font.
.TP
\fBBC\fP
Bold Small Capital font.
.TP
\fBIC\fP
Italic Small Capital font.
.TP
\fBBIC\fP
Bold Italic Small Capital font.
.TP
\fBA\fP
Acronym font (capital to small capital).
.TP
\fBBA\fP
Bold Acronym font.
.TP
\fBIA\fP
Italic Acronym font.
.TP
\fBBIA\fP
Bold Italic Acronym font.
.TP
\fBS\fP
Superscript font.
.TP
\fBBS\fP
Bold Superscript font.
.TP
\fBIS\fP
Italic Superscript font.
.TP
\fBBIS\fP
Bold Italic Superscript font.
.TP
\fBF\fP
Final font (glyphs that might only appear at the end of a
line).
.TP
\fBBF\fP
Bold Final font.
.TP
\fBIF\fP
Italic Final font.
.TP
\fBBIF\fP
Bold Italic Final font.
.TP
\fBP\fP
Return to previous font.
.
.
.
.SH NAMING CONVENTIONS
.PP
\fIUtmac\fR use some convention to name macro, strings, and
number register. Internally, files are divided in modules,
and the naming conventions are as follow:
.IP \(bu
The name of macros are of the form
\fBmodule:name\fP.
.IP \(bu
The name of strings and number registers are of the forme
\fBmodule‐name\fP.
.PP
Externally, all macro only contain uppercase letter and is
never longer than three letters.
.PP
So, \fIutmac\fP reserve the following names:
.IP \(bu
Names containing the charcters \fB:\fP and \fB‐\fP.
.IP \(bu
Names containing uppercase letters, and shorter
than four letters.
.
.
.
.SH EXAMPLE
.PP
The following example is a fully commented simple \fIutmac\fP
document. As a summary is inserted, two pass of \fItroff\fP
are needed. If the summary is longer than one page, a third
pass of troff would be needed to handle correctly the page
references, but this is not the case in this short example.
So, this document can be build using these commands:
.PP
.EX
troff -muh alice.tr \fB>\fR /dev/null
troff -muh alice.tr \fB|\fR dpost \fB|\fR ps2pdf - alice.pdf
.EE
.PP
.EX
\fB.\fR\fI\e" Start example\fR
\fB.\fR\fI\e" Use recto verso\fR
\fB.\fR\fBRV\fR
\fB.\fR\fI\e" Define metadatas\fR
\fB.\fR\fBDA\fR Lewis Carroll
\fB.\fR\fBDT\fR Alice’s adventures in wonderland and Through the looking glass
\fB.\fR\fBDK\fR alice nabuchodonosor jabberwocky
\fB.\fR\fI\e" Build first page\fR
\fB.\fR\fBH0\fR Lewis Carroll
\fB.\fR\fBH1\fR Alice’s adventures
\fB.\fR\fI\e" Insert a summary of chapter headings\fR
\fB.\fR\fBS2\fR
\fB.\fR\fI\e" Chapter heading\fR
\fB.\fR\fBH2\fR Alice’s adventures in wonderland
\fB.\fR\fI\e" A short exergue\fR
\fB.\fR\fBNT\fR
All in the golden afternoon
Full leisurly we glide
\fB.\fR\fBNE\fR
\fB.\fR\fI\e" First paragraph\fR
\fB.\fR\fBH3\fR Down the rabbitt hole
\fB.\fR\fI\e" Some text with font definitions, and a note appeal\fR
\fB.\fR\fBPP\fR
\fB\e*C\fPAlice\fB\e*P\fP was beginning to be very tired of sitting by her
sister on the bank, and of having nothing to do: once or
twice she had peeped into the book her sister was reading,
but it had no pictures or conversations in it, "\fB\e*I\fPand what
is the use of a book\fB\e*P\fP" thought \fB\e*C\fPAlice\fB\e*P\fP, "\fB\e*I\fPwithout
pictures or conversations?\fB\e*P\fP\fB\e**\fP"
\fB.\fR\fI\e" A note\fR
\fB.\fR\fBNS\fR
Yes, what is the use of such a book?
\fB.\fR\fBNE\fR
\fB.\fR\fI\e" Some other chapters and paragraphs...\fR
\fB.\fR\fBH3\fR The pool of tears
\fB.\fR\fBH2\fR Through the looking glass
\fB.\fR\fI\e" Table of content\fR
\fB.\fR\fBXT\fR
\fB.\fR\fI\e" Stop example\fR
.EE
.
.
.
.SH ENVIRONMENT
.TP
\fBTROFFMACS\fR
This is a \fItroff\fR environment variable, that \fIutmac\fR
use to find tmacs file. It must be defined for \fIutmac\fR
to work.
.TP
\fBTROFFONTS\fR
This is a \fItroff\fR environment variable that \fIutmac\fR
use to find font files. By default, this variable should
contain the path to the opentype libertine font.
.TP
\fBUTMAC\fR
Locale tmac file that \fIutmac\fR will load. It should
contain localization macros. See \fB@MACDIR@/u‐locale\fR for
an example.
.
.
.
.SH FILES
.PP
The following files are installed on the directory
@MACDIR@:
\fB@BIN@\fR
.
.
.
.SH SEE ALSO
.PP
u‐ref(7),
postxml(1),
idx(1),
refer(1).
.
.
.
.SH LICENSE
.PP
\fIUtmac\fR macros and this manual page are distributed under
a
two clause BSD
license.
.
.
.
.SH BUGS & HELP
.PP
Don’t hesitate to ask questions at help at utroff dot org.
Please, send bugs and patches at help at utroff dot org.
.
.
.
.SH AUTHOR
.PP
Pierre‐Jean \fCFichet\fR.
